@@ -1,5 +1,5 @@
 package MARC::Moose::Formater::UnimarcToMarc21;
-$MARC::Moose::Formater::UnimarcToMarc21::VERSION = '1.0.32';
+$MARC::Moose::Formater::UnimarcToMarc21::VERSION = '1.0.33';
 # ABSTRACT: Convert biblio record from UNIMARC to MARC21
 use Moose;
 
@@ -1013,7 +1013,7 @@ override 'format' => sub {
         # Skip $6 and $7
         my @sf;
         my $date_available = 0;
-        SUFIELD600:
+        SUBFIELD600:
         for ( @{$field->subf} ) {
             my ($letter, $value) = @$_;
             $value =~ s/^ *//; $value =~ s/ *$//;
@@ -1272,7 +1272,7 @@ MARC::Moose::Formater::UnimarcToMarc21 - Convert biblio record from UNIMARC to M
 
 =head1 VERSION
 
-version 1.0.32
+version 1.0.33
 
 =head1 SYNOPSYS
 
